#
# spec file for package dolphin
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf5_version 5.60.0
# Latest stable Applications (e.g. 17.08 in KA, but 17.11.80 in KUA)
%{!?_kapp_version: %define _kapp_version %(echo %{version}| awk -F. '{print $1"."$2}')}
%bcond_without lang
Name:           dolphin
Version:        20.04.2
Release:        lp152.1.1
Summary:        KDE File Manager
License:        GPL-2.0-or-later
Group:          Productivity/File utilities
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
Source3:        dolphinsu.desktop
Patch0:         dolphin-go_up.diff
# PATCH-FIX-OPENSUSE
Patch1:         0001-Revert-Disallow-executing-Dolphin-as-root-on-Linux.patch
BuildRequires:  extra-cmake-modules >= 1.6.0
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Activities) >= 5.7.0
BuildRequires:  cmake(KF5Baloo)
BuildRequires:  cmake(KF5BalooWidgets)
BuildRequires:  cmake(KF5Bookmarks) >= 5.7.0
BuildRequires:  cmake(KF5Completion) >= 5.7.0
BuildRequires:  cmake(KF5Config) >= 5.7.0
BuildRequires:  cmake(KF5CoreAddons) >= 5.7.0
BuildRequires:  cmake(KF5Crash)
BuildRequires:  cmake(KF5DBusAddons) >= 5.7.0
BuildRequires:  cmake(KF5DocTools) >= 5.7.0
BuildRequires:  cmake(KF5FileMetaData)
BuildRequires:  cmake(KF5I18n) >= 5.7.0
BuildRequires:  cmake(KF5IconThemes) >= 5.7.0
BuildRequires:  cmake(KF5Init) >= 5.7.0
BuildRequires:  cmake(KF5KCMUtils) >= 5.7.0
BuildRequires:  cmake(KF5KIO) >= 5.7.0
BuildRequires:  cmake(KF5NewStuff) >= 5.7.0
BuildRequires:  cmake(KF5Notifications) >= 5.7.0
BuildRequires:  cmake(KF5Parts) >= 5.7.0
BuildRequires:  cmake(KF5Solid) >= 5.7.0
BuildRequires:  cmake(KF5TextEditor) >= 5.7.0
BuildRequires:  cmake(KF5WindowSystem) >= 5.7.0
BuildRequires:  cmake(Phonon4Qt5)
BuildRequires:  cmake(Qt5Concurrent) >= 5.4.0
BuildRequires:  cmake(Qt5Core) >= 5.4.0
BuildRequires:  cmake(Qt5DBus) >= 5.4.0
BuildRequires:  cmake(Qt5Gui) >= 5.4.0
BuildRequires:  cmake(Qt5Widgets) >= 5.4.0
Requires:       baloo5-kioslaves
Requires:       dolphin-part = %{version}-%{release}
Recommends:     kio-extras5
Recommends:     konsole-part
Obsoletes:      dolphin5
%if %{with lang}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif

%description
This package contains the default file manager of KDE Workspaces.

%package part
Summary:        KDE File Manager
Group:          Productivity/File utilities
%requires_ge    kio
Recommends:     %{name}-part-lang
Obsoletes:      dolphin5-part

%description part
This package contains the libraries used by Dolphin and Konqueror.

%package -n libdolphinvcs5
Summary:        KDE File Manager
Group:          Productivity/File utilities

%description -n libdolphinvcs5
This package contains the libraries used by Dolphin and Konqueror.

%package devel
Summary:        KDE File Manager
Group:          Productivity/File utilities
Requires:       libdolphinvcs5 = %{version}
Obsoletes:      dolphin5-devel < %{version}
Provides:       dolphin5-devel = %{version}

%description devel
This package contains the libraries used by Dolphin and Konqueror.

%if %{with lang}
%package -n %{name}-part-lang
# FIXME: consider using %%lang_package macro
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name}-part = %{version}
Supplements:    (bundle-lang-other and %{name}-part)
Provides:       %{name}-lang = %{version}
Obsoletes:      %{name}-lang < %{version}
Provides:       %{name}-part-lang-all = %{version}
BuildArch:      noarch

%description -n %{name}-part-lang

Provides translations for the "%{name}" package.
%endif

%prep
%setup -q
%autopatch -p1

%build
  %cmake_kf5 -d build
  %cmake_build

%install
  %kf5_makeinstall -C build
  %if %{with lang}
    %find_lang %{name} --with-man --all-name
    %{kf5_find_htmldocs}
  %endif

  install -D -m 0644 %{SOURCE3} %{buildroot}%{_kf5_applicationsdir}/org.kde.dolphinsu.desktop
  %suse_update_desktop_file org.kde.dolphin          System FileManager

%post part -p /sbin/ldconfig
%postun part -p /sbin/ldconfig
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%post -n libdolphinvcs5 -p /sbin/ldconfig
%postun -n libdolphinvcs5 -p /sbin/ldconfig

%files
%license COPYING*
%doc README
%dir %{_kf5_appstreamdir}
%dir %{_kf5_htmldir}
%dir %{_kf5_htmldir}/en
%dir %{_kf5_sharedir}/kglobalaccel/
%doc %lang(en) %{_kf5_htmldir}/en/dolphin/
%{_kf5_applicationsdir}/org.kde.dolphin.desktop
%{_kf5_applicationsdir}/org.kde.dolphinsu.desktop
%{_kf5_appstreamdir}/org.kde.dolphin.appdata.xml
%{_kf5_bindir}/dolphin
%{_kf5_bindir}/servicemenuinstaller
%{_kf5_dbusinterfacesdir}/org.freedesktop.FileManager1.xml
%{_kf5_libdir}/libkdeinit5_dolphin.so
%{_kf5_sharedir}/dbus-1/services/org.kde.dolphin.FileManager1.service
%{_kf5_sharedir}/kglobalaccel/org.kde.dolphin.desktop

%files part
%license COPYING*
%doc README
%config %{_kf5_configdir}/servicemenu.knsrc
%dir %{_kf5_configkcfgdir}
%dir %{_kf5_plugindir}
%dir %{_kf5_servicesdir}
%dir %{_kf5_servicetypesdir}
%{_kf5_configkcfgdir}/dolphin_*.kcfg
%{_kf5_libdir}/libdolphinprivate.so.*
%{_kf5_plugindir}/dolphinpart.so
%{_kf5_plugindir}/kcm_dolphin*.so
%{_kf5_servicesdir}/dolphinpart.desktop
%{_kf5_servicesdir}/kcmdolphingeneral.desktop
%{_kf5_servicesdir}/kcmdolphinnavigation.desktop
%{_kf5_servicesdir}/kcmdolphinservices.desktop
%{_kf5_servicesdir}/kcmdolphinviewmodes.desktop
%{_kf5_servicetypesdir}/fileviewversioncontrolplugin.desktop
#{_kf5_sharedir}/dolphinpart/
%{_kf5_debugdir}/dolphin.categories

%files -n libdolphinvcs5
%license COPYING*
%doc README
%{_kf5_libdir}/libdolphinvcs.so.*

%files devel
%license COPYING*
%doc README
%{_includedir}/dolphinvcs_export.h
%{_kf5_cmakedir}/DolphinVcs/
%{_kf5_libdir}/libdolphinvcs.so
%{_kf5_prefix}/include/Dolphin/
%{_kf5_prefix}/include/dolphin_export.h

%if %{with lang}
%files part-lang -f %{name}.lang
%license COPYING*
%dir %{_kf5_sharedir}/locale/fi/LC_SCRIPTS/
%lang(fi) %{_kf5_sharedir}/locale/fi/LC_SCRIPTS/dolphin/
%endif

%changelog
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- Changes since 20.04.1:
  * Show progress when duplicating items (kde#422335)
  * use KSycoca for updating OpenPreferredSearchTool action
  * Left-elide file/folders while keeping their extension visible (kde#404955)
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- Changes since 20.04.0:
  * Don't update preferred search action on window activation
  * Don't use local URL for KMoreTool (kde#420911)
  * Fixes Dolphin crash on "Defocus Terminal Panel" menu click if no Konsole is installed.
  * Dolphin Service Installer: Run uninstall scripts, rename methods
  * Dolphin Service Menu installer cleanup
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- Changes since 20.03.90:
  * Dolphin Service Installer: Run uninstall scripts, rename methods
  * Dolphin Service Menu installer cleanup
  * Sort services list alphabetically (kde#419938)
  * Display readable titlebar text while using search and full paths in titlebar (kde#406624)
  * Dolphin Services: Launch Deb/Rpm archives with QDesktopServices
  * Fix crashing on starting and quitting (kde#419585)
  * Use same logic for "no extension" case with Duplicate feature (kde#419070)
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- Changes since 20.03.80:
  * Update dragCursor while dragging
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Too many changes since 19.12.3, only listing bugfixes:
  * Fixes multiple KVersionControlPlugin::fileName() calls on entering or updating directory. (kde#415698)
  * Restore former position of "Create New" menu item in viewport context menu (kde#417640)
  * Add natural sorting and case-insensitive sorting for all role-types (kde#406296)
  * Fixes multiple VCS plugin calls on single directory update. (kde#415698)
  * Use QDesktopServices to open urls not supported by dolphin (kde#372642)
  * Use more conventional "Add to Places" text for that action (kde#416064)
  * make link with LLVM (kde#410237)
  * Allow dolphin to format DateTime at later stage than KBalooRolesProvider (kde#411173)
- Dropped patches, now upstream:
  * 0001-Restore-former-position-of-Create-New-menu-item-in-v.patch
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- Changes since 19.12.2:
  * Fix typo in comment
  * Fix files not being highlighted if directory of file is already open (kde#417230)
* Wed Feb 26 2020 Luca Beltrame <lbeltrame@kde.org>
- Add upstream patch to move back the "Create New..." menu item
  in its former position (kde#417640):
  * 0001-Restore-former-position-of-Create-New-menu-item-in-v.patch
- Refreshed patches:
  * dolphin-go_up.diff
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- Changes since 19.12.1:
  * Change drop indicator color (kde#415010)
  * Hide tooltip instantly on filter change
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- Changes since 19.12.0:
  * Update Appstream for new release
  * Improve scroll wheel speed by basing it on label height, not icon height (kde#386379)
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- Changes since 19.11.90:
  * Fix build with Qt 5.14 RC (kde#414492)
  * Correct invalid homepage URL (kde#414901)
  * Update Appstream for new release
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- Changes since 19.11.80:
  * fix(search): Fix baloo searchString parsing (kde#412952)
  * Force dbus introspection on the Dolphin_1 object (kde#414402)
  * Fix accessibility regression on the Dolphin Control button
  * Fix dolphin homepage in the appstream metadata
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Too many changes since 19.08.3, only listing bugfixes:
  * [Status Bar] Remove file status Timer, add text update delay (kde#399267)
  * When the selection is deselected, restart the keyboard search from the beginning (kde#411538)
  * Expose full set of script execution options in settings window (kde#371837)
  * Fix wrong window titles (kde#389135)
  * Add "Add to Places" action to file menu (kde#390757)
  * [dolphin] Add an action to toggle the searchbar (kde#344617)
  * Make non-empty textual columns come first in sorting (kde#410538)
  * Middle-elide file/folder labels so the extension is always visible (kde#404955)
  * Correct "New Window" tooltip (kde#411215)
  * Fix an issue with focus lost after closing terminal panel (kde#407979)
  * Fix name grouping feature for cyrillic names (kde#406867)
  * Fix an issue with a new tab focus (kde#407604)
- Refreshed patches:
  * 0001-Revert-Disallow-executing-Dolphin-as-root-on-Linux.patch
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- No code change since 19.08.2
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- Changes since 19.08.1:
  * Fix crash when lauching dolphin with a search scheme
  * Update searchbox on URL changes (Fix D24369)
  * Update searchbar parameters on URL change
  * Bring back placesitemmodeltest
  * Fix ascending/descending choosers getting unchecked when re-selecting the same sort order (kde#411223)
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- Changes since 19.08.0:
  * Fixing bugs in new folders in tabs feature
  * Making sure that DBus objects are all created before the service
  * Fix places text when the URL has a trailing slash
  * Reset progress bar text when directory loading starts
  * Fixing bug where split view opens with no URLs (kde#411193)
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- Changes since 19.07.90:
  * Fix build with cmake < 3.7
  * Do not match daemonized dolphin instances: part 2
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- Changes since 19.07.80:
  * Fix dir change when show hidden terminal panel with running program in it
  * servicemenuinstaller: Fix placeholders in i18n string
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * Too many changes to list here
- Refreshed patches:
  * 0001-Revert-Disallow-executing-Dolphin-as-root-on-Linux.patch
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- Changes since 19.04.2:
  * [Places Panel] Pass iconName to KFilePlaceEditDialog
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- Changes since 19.04.1:
  * Elide tab titles left so key information at the end of the string doesn't get cut off (kde#406569)
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- Changes since 19.04.0:
  * [PlacesItemModelTest] Ignore user tag places
  * Try again to fix PlacesItemModelTest::testDefaultViewProperties()
  * Fix dolphin cannot be added as favourite in GNOME (kde#407198)
  * Fix missing update of file name label in information panel without preview
  * Fix adding "Create New..." menu to toolbar (kde#405780)
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- Changes since 19.03.90:
  * Don't show "Open With" menu items for empty directories
  * [DolphinMainWindowTest] Fix testNewFileMenuEnabled
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * Move Safely Remove down in places context menu
  * When hovering over a file on the not-focus view panel, the information panel gets updated
  * [InformationPanel] Hide the video when the preview is disabled, avoid computing the preview when it is disabled
  * Revert "Create a global launch shortcut (Meta+E)"
  * [PhononWidget] Fix layout warning
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Too many changes to list here
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * Fix crash during shutdown (kde#402784)
  * Word-wrap KMessageWidget text
  * [DolphinView] Use correct color group
  * Sort preview plugins case-insensitively
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * Fix member initialization
  * [versioncontrolobserver] Update working directory on tab activation
  * [versioncontrolobserver] Do not use static plugin objects
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * fix display of image orientation
  * Fix title update when changing active split view (kde#402641)
  * Use https over http for homepage url
  * Add failing test case for bug #402641
  * Use correct icon for the "New Window" menu item
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * KItemListWidget: Use initStyleOption
  * Fix selection when navigating back, with size sorting. (kde#352296)
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * Do not disconnect all StorageAccess signals when unmounting (kde#400992)
  * Improve Ux for the places panel's hidden items (kde#400860)
  * move kcrash link to dolphin app (which is the effective user)
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Too many changes to list here
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * Don't enable two-clicks renaming in single-click mode
  * [KStandardItemListWidget] Pass icon state to overlay painter
  * Update hidden state correctly (kde#399599)
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * [PlacesItemModelTest] More index-related fixes
  * [PlacesItemModel] Fix testSystemItems()
  * [PlacesItemModelTest] Fix testHideItem()
  * [PlacesItemModelTest] Fix testTearDownDevice()
  * [PlacesItemModelTest] Fix testDeletePlace()
  * [PlacesItemModelTest] Fix testGroups() test case
  * Follow-up of commit 9760f9607d
  * [PlacesItemModelTest] Check whether Desktop and Download folders exist
  * Fix disabling of DolphinNewFileMenu
  * Add test cases for enabled status of DolphinNewFileMenu
  * Fix that dragging a file can trigger inline rename. (kde#398375)
  * Don't assign twice the same key to the action New Tab (kde#398324)
  * Do use QIcon::Selected for non-icon view
  * [KStandardItemListWidget] Round to icon size before applying scaling
  * Correctly save behaviourOnLaunch (kde#398022)
  * Don't use QIcon::Selected state for selected icon (kde#398014)
- Dropped patches, now upstream:
  * Fix-that-dragging-a-file-can-trigger-inline-rename.patch
  * Dont-assign-twice-the-same-key-to-the-action-New-Tab.patch
* Wed Oct  3 2018 wbauer@tmo.at
- Add Fix-that-dragging-a-file-can-trigger-inline-rename.patch to
  prevent accidentally triggering inline rename by just dragging a
  file (boo#1108797, kde#398375)
* Thu Sep 27 2018 wbauer@tmo.at
- Add Dont-assign-twice-the-same-key-to-the-action-New-Tab.patch to
  avoid an "Ambiguous shortcuts" error on startup when running
  dolphin on a different desktop than Plasma
  (boo#1109372, kde#398324)
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * Pretty-print "creationtime" role
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * Remove custom icon selection for trash
  * Compare UDS entry times directly instead of going through KFileItem
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Too many changes to list here
- Refreshed patches:
  * 0001-Revert-Disallow-executing-Dolphin-as-root-on-Linux.patch
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * Fix loop of FocusIn events
  * [KBalooRolesProvider] Support properties of type QStringList (kde#395033)
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * Fix crash in PlacesItem::setUrl() (kde#394507)
  * Add missing i18n call (kde#394194)
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * Don't filter out duplicated entries from places panel (kde#393528)
  * Update window title after closing split view (kde#385111)
  * Add failing test case for bug #385111
  * Fix inconsistent preview spacing and icon wiggly-ness when toggling previews in Icon mode (kde#393306)
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * Fix untranslated places panel entries (kde#392822)
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Too many changes to list here
- Refresh patches:
  * 0001-Revert-Disallow-executing-Dolphin-as-root-on-Linux.patch
  * dolphin-go_up.diff
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * Fix resetting "View Modes" preferences to defaults
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * Let the terminal panel dock to any part of the window (kde#362593)
  * Folderspanel's context-menu option "Limit to Home Directory" is always visible
  * folderspanel context-menu option "Limit to Home Directory" should be always visible
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * infopanel fully resizable
  * Revive folderpanel when outside $HOME
  * Ignore baloo urls created from new KIO model (kde#387888)
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * appdata: update doc URL, more https
  * Use CMakePackageConfigHelpers instead of the ECM variant
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * Fix scrolling during inline renaming causes rename of wrong file (kde#378786)
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Too many changes to list here
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * None
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * Fix build with Qt 5.10
  * Keep renamed file(s) in view
  * Make sure we always have Shift+Del as shortcut
  * Qt 5 Porting: Q_WS_WIN -> Q_OS_WIN
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * None
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
  * Fix loading of dolphinui.rc (kde#382848)
  * Use https for knsrc providers
  * Fix drop menu position with urlnavigator drops
  * Bundle the XMLGUI files into qrc resources.
  * Add role for file creation time.
  * Fix knewstuff popup menu position on wayland
  * Add missing emit keywords
  * [Places Panel] Disallow editing devices
  * Support "Deletion Time" role in Trash (kde#153492)
  * Drop unnecessary method
  * Introduce DolphinMainWindowTest
  * Move non-exported code to a static library
  * add few more Q_DECL_OVERRIDE
  * Port tests from ecm_mark_as_test to ecm_add_test
  * Fix kfileitemmodeltest
  * Remove define to disable exports
  * Fix some compiler warnings
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * Change in "Open in new tab" feature in Dolphin
  * Ignore drops-onto-items from invalid places items (kde#373005)
* Wed Jul 12 2017 fabian@ritter-vogt.de
- Replace %%lang_package with evaluated macro to be able to add proper
  Provides/Obsoletes to avoid file conflicts during installation
* Fri Jul  7 2017 wbauer@tmo.at
- Rename -lang package to dolphin-part-lang and recommend it by the
  dolphin-part package, the translations are used by the kpart too
  * Avoid boo#1027925 in the context of boo#1047665
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * Correct searchbox, split view transitions between tabs (kde#379135, kde#380032)
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * Don't ignore tag clicks in the tooltips
  * Sort the tag-values alphabetically in the "Tags" column (kde#377589)
* Sat Apr 22 2017 fabian@ritter-vogt.de
- Add patch to re-allow running dolphin as root:
  * 0001-Revert-Disallow-executing-Dolphin-as-root-on-Linux.patch
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * None
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * Update name of the delete action in the .rc files
  * behavior change -> New Window opens with same URL
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * Too many changes to list here
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * None
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Sun Nov  6 2016 wbauer@tmo.at
- Recommend kio-extras5 instead of kio_mtp5, the latter doesn't
  exist any more and is part of kio-extras5 now.
* Wed Oct 12 2016 lbeltrame@kde.org
- Drop properly-check-Shift-toggling.patch, upstreamed
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
- https://www.kde.org/announcements/announce-applications-16.08.2.php
* Wed Sep 21 2016 wbauer@tmo.at
- Add properly-check-Shift-toggling.patch to fix toggling the
  "Move to Trash"/"Delete" actions in the context menu when
  pressing Shift (kde#354301)
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.08-rc.php
* Thu Jul  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Wed Jun 15 2016 alarrosa@suse.com
- Require baloo5-kioslaves so dolphin doesn't show an "Invalid
  protocol" error when trying to find a file because the
  baloosearch kioslave is not installed.
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
- Drop upstreamed patch specify-fallback-icon.patch
* Tue Apr 26 2016 wbauer@tmo.at
- Added specify-fallback-icon.patch: fixes missing icons for
  certain filetypes where the specified icon doesn't exist
  (kde#358958, kde#361034)
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
- Drop upstreamed patch Fix-wrong-path-URL-conversion.patch
* Fri Mar 25 2016 wbauer@tmo.at
- Added Fix-wrong-path-URL-conversion.patch: fixes display of
  additional file metadata in dolphin's filelist for indexed files
  (boo#970896)
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Fri Feb 26 2016 wbauer@tmo.at
- Remove the --icon parameter (%%i) from the command line in
  dolphinsu.desktop, it isn't necessary and it makes dolphin crash
  on exit due to a bug in Frameworks (boo#965514, kde#359758)
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
- Drop upstreamed patches:
  * fix-check-for-session-close.patch
  * Do-not-delete-sub-menus-of-the-control-menu-explicitly.patch
* Thu Jan 28 2016 wbauer@tmo.at
- Added fix-check-for-session-close.patch: don't ask for
  confirmation on logout when storing the session
  (boo#953014, kde#353548)
* Thu Jan 14 2016 wbauer@tmo.at
- Added Do-not-delete-sub-menus-of-the-control-menu-explicitly.patch:
  fixes a possible crash when closing the "Control" menu (boo#952460,
  kde#354558)
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Sun Nov 29 2015 tittiatcoke@gmail.com
- Move the installed appdata file to the correct naming to
  fix bnc#957041
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
- Drop upstreamed patch:
  allow-home-directories-with-non-local-file-paths.patch
* Sun Oct 25 2015 hrvoje.senjan@gmail.com
- Added allow-home-directories-with-non-local-file-paths.patch
  (boo#950883, kde#352743, kde#353550)
* Wed Oct 21 2015 wbauer@tmo.at
- Install dolphinsu.desktop as org.kde.dolphinsu.desktop to prevent
  it being overridden by an old KDE4 entry in ~/.local/share/applications/
* Mon Oct 19 2015 wbauer@tmo.at
- Fix dolphinsu.desktop: the KF5 based dolphin doesn't support
  "-caption" any more (boo#950907)
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
